{ config, disko, ... }:
{
  imports = [ disko.nixosModules.disko ];

  disko.devices = {
    disk = {
      "${config.networking.hostName}" = {
        type = "disk";
        device = "/dev/nvme0n1";
        content = {
          type = "gpt";
          partitions = {
            boot = {
              size = "1M";
              type = "EF02";
            };
            ESP = {
              size = "2G";
              type = "EF00";
              content = {
                type = "filesystem";
                format = "vfat";
                mountpoint = "/boot";
                mountOptions = [ "umask=0077" ];
              };
            };
            main = {
              size = "100%";
              content = {
                type = "lvm_pv";
                vg = "${config.networking.hostName}";
              };
            };
          };
        };
      };
    };

    lvm_vg = {
      "${config.networking.hostName}" = {
        type = "lvm_vg";
        lvs = {
          root = {
            size = "100%";
            content = {
              type = "btrfs";
              extraArgs = [ "-f" ];
              subvolumes = {
                "/root" = {
                  mountpoint = "/";
                  mountOptions = [
                    "compress=zstd"
                    "ssd"
                  ];
                };
                "/prev" = {
                  mountpoint = "/prev";
                  mountOptions = [
                    "compress=zstd"
                    "noexec"
                    "ssd"
                  ];
                };
                "/nix" = {
                  mountpoint = "/nix";
                  mountOptions = [
                    "compress=zstd"
                    "ssd"
                  ];
                };

                # Impermanence
                "/persist" = {
                  mountpoint = "/persist";
                  mountOptions = [
                    "compress=zstd"
                    "ssd"
                  ];
                };
                "/persist/.snapshots" = { };
                "/persist/home" = { };
                "/persist/home/.snapshots" = { };
              };
            };
          };
          swap = {
            size = "2G";
            content = {
              type = "swap";
              discardPolicy = "both";
            };
          };
        };
      };
    };
  };

  # Needed for impermanence
  fileSystems."/persist".neededForBoot = true;
}
